"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PrettyConsole = void 0;

var _toSplunkEvent = require("./toSplunkEvent");

var _isPresent = require("./utils/logic/isPresent");

var _formatTime = require("./utils/time/formatTime");

var _omit = require("./utils/object/omit");

var _ConsoleLevel = require("./ConsoleLevel");

const messageFormatSplunkLog = log => {
  if (log.workflowType) {
    return `[${log.workflowType}] ${log.msg}`;
  }

  return log.msg ?? '';
};

const messageFormat = log => {
  if ((0, _toSplunkEvent.isSplunkLog)(log)) {
    return messageFormatSplunkLog(log);
  }

  return '';
};

const defaultIgnore = ['level', 'time', 'msg', 'account', 'workflowType'];

const print = (log, level, ignore = defaultIgnore) => {
  if ((0, _toSplunkEvent.isSplunkLog)(log)) {
    const messages = [];
    const logLevel = level ?? (0, _ConsoleLevel.getConsoleLevelFromSplunkLog)(log);
    messages.push(`[${(0, _formatTime.formatTime)(new Date(log.time))}]: ${messageFormatSplunkLog(log)}`);
    const event = (0, _omit.omit)(ignore, log);

    if ((0, _isPresent.isPresent)(event)) {
      messages.push(event);
    } // eslint-disable-next-line no-console


    console[logLevel](...messages);
  } else {
    console.error(log);
  }
};

const PrettyConsole = {
  messageFormat,
  print,
  defaultIgnore
};
exports.PrettyConsole = PrettyConsole;